@@ -159,8 +159,8 @@ pub(crate) fn numpy_2_0_deprecation(checker: &mut Checker, expr: &Expr) {
 
     let maybe_replacement = checker
         .semantic()
-        .resolve_call_path(expr)
-        .and_then(|call_path| match call_path.as_slice() {
+        .resolve_qualified_name(expr)
+        .and_then(|qualified_name| match qualified_name.segments() {
             // NumPy's main namespace np.* members removed in 2.0
             ["numpy", "add_docstring"] => Some(Replacement {
                 existing: "add_docstring",
