@@ -25,6 +25,7 @@ pub(crate) use import_private_name::*;
 pub(crate) use import_self::*;
 pub(crate) use invalid_all_format::*;
 pub(crate) use invalid_all_object::*;
+pub(crate) use invalid_bool_return::*;
 pub(crate) use invalid_envvar_default::*;
 pub(crate) use invalid_envvar_value::*;
 pub(crate) use invalid_str_return::*;
@@ -37,15 +38,18 @@ pub(crate) use magic_value_comparison::*;
 pub(crate) use manual_import_from::*;
 pub(crate) use misplaced_bare_raise::*;
 pub(crate) use named_expr_without_context::*;
+pub(crate) use nan_comparison::*;
 pub(crate) use nested_min_max::*;
 pub(crate) use no_method_decorator::*;
 pub(crate) use no_self_use::*;
 pub(crate) use non_ascii_module_import::*;
 pub(crate) use non_ascii_name::*;
 pub(crate) use non_slot_assignment::*;
+pub(crate) use nonlocal_and_global::*;
 pub(crate) use nonlocal_without_binding::*;
 pub(crate) use potential_index_error::*;
 pub(crate) use property_with_parameters::*;
+pub(crate) use redeclared_assigned_name::*;
 pub(crate) use redefined_argument_from_local::*;
 pub(crate) use redefined_loop_name::*;
 pub(crate) use repeated_equality_comparison::*;
@@ -54,6 +58,8 @@ pub(crate) use repeated_keyword_argument::*;
 pub(crate) use return_in_init::*;
 pub(crate) use self_assigning_variable::*;
 pub(crate) use single_string_slots::*;
+pub(crate) use singledispatch_method::*;
+pub(crate) use singledispatchmethod_function::*;
 pub(crate) use subprocess_popen_preexec_fn::*;
 pub(crate) use subprocess_run_without_check::*;
 pub(crate) use super_without_brackets::*;
@@ -78,6 +84,7 @@ pub(crate) use unnecessary_lambda::*;
 pub(crate) use unnecessary_list_index_lookup::*;
 pub(crate) use unspecified_encoding::*;
 pub(crate) use useless_else_on_loop::*;
+pub(crate) use useless_exception_statement::*;
 pub(crate) use useless_import_alias::*;
 pub(crate) use useless_return::*;
 pub(crate) use useless_with_lock::*;
@@ -111,6 +118,7 @@ mod import_private_name;
 mod import_self;
 mod invalid_all_format;
 mod invalid_all_object;
+mod invalid_bool_return;
 mod invalid_envvar_default;
 mod invalid_envvar_value;
 mod invalid_str_return;
@@ -123,15 +131,18 @@ mod magic_value_comparison;
 mod manual_import_from;
 mod misplaced_bare_raise;
 mod named_expr_without_context;
+mod nan_comparison;
 mod nested_min_max;
 mod no_method_decorator;
 mod no_self_use;
 mod non_ascii_module_import;
 mod non_ascii_name;
 mod non_slot_assignment;
+mod nonlocal_and_global;
 mod nonlocal_without_binding;
 mod potential_index_error;
 mod property_with_parameters;
+mod redeclared_assigned_name;
 mod redefined_argument_from_local;
 mod redefined_loop_name;
 mod repeated_equality_comparison;
@@ -140,6 +151,8 @@ mod repeated_keyword_argument;
 mod return_in_init;
 mod self_assigning_variable;
 mod single_string_slots;
+mod singledispatch_method;
+mod singledispatchmethod_function;
 mod subprocess_popen_preexec_fn;
 mod subprocess_run_without_check;
 mod super_without_brackets;
@@ -164,6 +177,7 @@ mod unnecessary_lambda;
 mod unnecessary_list_index_lookup;
 mod unspecified_encoding;
 mod useless_else_on_loop;
+mod useless_exception_statement;
 mod useless_import_alias;
 mod useless_return;
 mod useless_with_lock;
